// File: DaysElapsedInYear.java 
/**
    GUI class interaction with inheritance/polymorphism Example 
    @author		Dr. Spiegel
*/

import java.io.*;
import java.util.*;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/** 
    Determine the number of days into a year for any date 
*/
public class DaysElapsedInYear extends JFrame implements ActionListener, WindowListener {

 JLabel monthPrompt;
 JLabel dayPrompt;
 JLabel yearPrompt;
 JTextField month;
 JTextField day;
 JTextField year;
 JLabel output;

 /**
      No variable of type LeapYear
      Year can refer to either a leap year or a regular year 
*/
 Year theDate;

/**
      Constructor sets up the Frame 
*/
 DaysElapsedInYear()
 {setSize(200,240);

  // First, the Frame will have two items, the interface and the result
  // Use either a border layout with north/south, or a grid layout with
  //     one column and two rows.
  // We'll use a grid layout with two rows, one column, and a gap of 5
  //       pixels between the areas
  getContentPane().setLayout(new GridLayout(2,1,5,5));
  final int frameWidth=40;
  getContentPane().setSize(frameWidth,80);

  getContentPane().setBackground(Color.black);

  // Now, set up a Panel to hold the interface
  JPanel Interface=new JPanel();

  // Set size of this panel
  Interface.setSize(frameWidth,60);

  // Set background color of interface panel
  Color InterfaceBGColor=Color.orange;
  Interface.setBackground(InterfaceBGColor);

  // The panel will have a border layout, with month on top (north),
  //     day in the center and year on the bottom (south).
  //     There will be a 25 pixel gap between each area
  Interface.setLayout(new BorderLayout());

  // Add a fancy border to the Interface panel
  Interface.setBorder(BorderFactory.createEtchedBorder(Color.orange,Color.blue));

  // Add window listener for the JFrame
  addWindowListener(this);

  // Now, add the individual interfaces for month, day and year. Each will
  //      be in its own JPanel
  JPanel pMonth=new JPanel(new FlowLayout(FlowLayout.LEFT));
  // Set size of panel
  pMonth.setSize(frameWidth,15);

  pMonth.setBackground(InterfaceBGColor);

  // Need a prompt
  monthPrompt=new JLabel("Enter the month");
  // Place the prompt on the panel
  pMonth.add(monthPrompt);
  // Need a textfield to read the month
  month=new JTextField(2);
  // Add it to the panel
  pMonth.add(month);
  // Need an action listener for this JTextField
  month.addActionListener(this);
  // Add the JPanel to the Interface
  Interface.add(pMonth,BorderLayout.NORTH);

  JPanel pDay=new JPanel(new FlowLayout(FlowLayout.LEFT));
  pDay.setSize(frameWidth,15);
  pDay.setBackground(InterfaceBGColor);
  dayPrompt=new JLabel("Enter the day     ");
  pDay.add(dayPrompt);
  day=new JTextField(2);
  pDay.add(day);
  day.addActionListener(this);
  Interface.add(pDay,BorderLayout.CENTER);

  JPanel pYear=new JPanel(new FlowLayout(FlowLayout.LEFT));
  pYear.setSize(frameWidth,15);
  pYear.setBackground(InterfaceBGColor);
  yearPrompt=new JLabel("Enter the year   ");
  pYear.add(yearPrompt);
  year=new JTextField(4);
  pYear.add(year);
  year.addActionListener(this);
  Interface.add(pYear,BorderLayout.SOUTH);

  // Set up Panel to hold Result label. Label will be left justified
  JPanel Result=new JPanel();
  Result.setSize(frameWidth,10);
  Result.setBackground(Color.cyan);
  Result.setLayout(new FlowLayout(FlowLayout.LEFT));
  output=new JLabel("                                        ");
  output.setForeground(Color.red);
  Result.add(output);

  // Add the panels to the frame
  getContentPane().add(Interface);  // Java 4 required getContentPane()
  getContentPane().add(Result);
  setVisible(true);
 }

/**
      WindowListener implementations
*/      
 public void windowClosed(WindowEvent event) {}
 public void windowDeiconified(WindowEvent event) {}
 public void windowIconified(WindowEvent event) {}
 public void windowActivated(WindowEvent event) {}
 public void windowDeactivated(WindowEvent event) {}
 public void windowOpened(WindowEvent event) {}
 public void windowClosing(WindowEvent event) { System.exit(0); }

 /**
     Invoked when Enter key is pressed 
     @param event		Holds info on the event that triggered this method
 */
 public void actionPerformed(ActionEvent event)
 {int m=Integer.parseInt(month.getText());
  int d=Integer.parseInt(day.getText());
  int y=Integer.parseInt(year.getText());
  month.setText("");
  day.setText("");
  year.setText("");
  // Initialize theDate to refer to the correct object type
  if (LeapYear.isLeapYear(y))
	  theDate=new LeapYear(m,d,y);
  else
	  theDate=new Year(m,d,y);
  output.setText("Days Elapsed:"+theDate.daysElapsed());
 }

/** 
      Just instantiate the Frame subclass and off it goes...
*/
 public static void main (String[] args) throws java.io.IOException
 {DaysElapsedInYear dFrame=new DaysElapsedInYear();
  dFrame.setResizable(true);
 }

}
